Module: MyPath
- Defined in:
- lib/mypath.rb,
lib/mypath/handler.rb,
lib/mypath/handler/cwd.rb,
lib/mypath/handler/gem.rb
Defined Under Namespace
Classes: Handler
Class Method Summary collapse
-
.local_path_for(path) ⇒ Object
Insstead of just finding one based on can_handle, it should call each in turn until it gets a path.
Class Method Details
.local_path_for(path) ⇒ Object
Insstead of just finding one based on can_handle, it should call each in turn until it gets a path
10 11 12 13 14 15 |
# File 'lib/mypath.rb', line 10 def local_path_for(path) handler = Handler.for(path) if handler handler.local_path end end |